@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Role::RepoFileInjector; # git description: v0.005-4-ge3a0ed4
+package Dist::Zilla::Role::RepoFileInjector; # git description: v0.006-2-gaf009ca
 # ABSTRACT: Create files outside the build directory
 # KEYWORDS: plugin distribution generate create file repository
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 
 use Moose::Role;
 
@@ -98,7 +98,10 @@ sub write_repo_files
         Carp::croak("attempted to write $filename multiple times") if -e $filename;
         $filename->touchpath;
 
-        $filename->spew_raw($file->encoded_content);
+        # handle dzil v4 files by assuming no (or latin1) encoding
+        my $encoded_content = $file->can('encoded_content') ? $file->encoded_content : $file->content;
+
+        $filename->spew_raw($encoded_content);
         chmod $file->mode, "$filename" or die "couldn't chmod $filename: $!";
     }
 }
@@ -117,7 +120,7 @@ Dist::Zilla::Role::RepoFileInjector - Create files outside the build directory
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
